%{!?kernel_version: %{expand: %%define kernel_version %(uname -r| perl -pe 's/-[a-zA-Z].*?$//g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %%define type %(uname -r| perl -pe 's/.*-//g')}}

%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}-%{type}
%define kmp_version %version

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vsock'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,9
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl --os=linux,sle,9 --release=%{kernel_dir} --build 2092844 --modKey %{modKey}

Name:         vmware-tools-vsock
BuildRequires: kernel-source kernel-syms
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vsock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.0.0
Release:      5.sles9
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vsock-configModule.tar.gz

Source0:      vsock.tar

%prep
%setup -n vsock-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vsock" = "vsock" -o "vsock" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vsock module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
install -m 644 -D ../vsock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/vmware/vsock.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vsock.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package common
Summary:      Contains the common files used by all the vsock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      5.sles9
Version:      9.4.10

%description common
 This package contains the common system configuration and scripts responsible for loading the vsock kernel module.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package kmp-%{type}
Summary:      The vsock kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vsock-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vsock-kmp
Release:      %{kversionreltag}.5.sles9
Requires: vmware-tools-vmci-kmp-%{type} = %{?epoch:%{epoch}:}1.0.15.0

%description kmp-%{type}
 This package contains a pre-compiled vsock module for use with the %{kernel_version} kernel.   The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vsock stop || true
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/insserv -r vsock /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VSOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,9 --dbAddAnswer VSOCK_NAME,vsock
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl --os=linux,sle,9 --toConfigure=vsock
if [ -e /etc/init.d/vsock ]; then
   /sbin/insserv -f vsock >/dev/null 2>&1
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/vmware/vsock.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*-//g'`
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vsock start || true
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/insserv -r vsock /dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,sle,9 --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,sle,9 --dbDelAnswer VSOCK_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   kmodType=`uname -r | sed -e 's/.*-//g'`
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vsock stop || true
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl
/etc/init.d/vsock

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/vmware/vsock.ko
